@@ -202,7 +202,7 @@ gdaui_basic_form_get_type (void)
 			0
 		};
 
-		type = g_type_register_static (GTK_TYPE_VBOX, "GdauiBasicForm", &info, 0);
+		type = g_type_register_static (GTK_TYPE_BOX, "GdauiBasicForm", &info, 0);
 	}
 
 	return type;
@@ -408,10 +408,12 @@ gdaui_basic_form_init (GdauiBasicForm *wid)
 	wid->priv->show_actions = FALSE;
 	wid->priv->entries_auto_default = FALSE;
 
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (wid), GTK_ORIENTATION_VERTICAL);
+
 	evbox = gtk_event_box_new ();
 	gtk_widget_show (evbox);
 	gtk_box_pack_start (GTK_BOX (wid), evbox, TRUE, TRUE, 0);
-	wid->priv->mainbox = gtk_vbox_new (FALSE, 0);
+	wid->priv->mainbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show (wid->priv->mainbox);
 	gtk_container_add (GTK_CONTAINER (evbox), wid->priv->mainbox);
 	g_object_set (evbox, "visible-window", FALSE, NULL);
@@ -1262,19 +1264,19 @@ load_xml_layout_children (GdauiBasicForm *form, xmlNodePtr parent_node)
 	prop = xmlGetProp (parent_node, BAD_CAST "container");
 	if (prop) {
 		if (xmlStrEqual (prop, BAD_CAST "columns")) {
-			top = gtk_hbox_new (FALSE, 0);
+			top = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 			ctype = TOP_BOX;
 		}
 		if (xmlStrEqual (prop, BAD_CAST "rows")) {
-			top = gtk_vbox_new (FALSE, 0);
+			top = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 			ctype = TOP_BOX;
 		}
 		else if (xmlStrEqual (prop, BAD_CAST "hpaned")) {
-			top = gtk_hpaned_new ();
+			top = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 			ctype = TOP_PANED;
 		}
 		else if (xmlStrEqual (prop, BAD_CAST "vpaned")) {
-			top = gtk_vpaned_new ();
+			top = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
 			ctype = TOP_PANED;
 		}
 		else 
@@ -1282,7 +1284,7 @@ load_xml_layout_children (GdauiBasicForm *form, xmlNodePtr parent_node)
 		xmlFree (prop);
 	}
 	if (!top)
-		top = gtk_hbox_new (FALSE, 0);
+		top = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
 	xmlNodePtr child;
 	for (child = parent_node->children; child; child = child->next) {
@@ -1398,7 +1400,7 @@ load_xml_layout_column (GdauiBasicForm *form, xmlNodePtr box_node)
 				if (! form->priv->place_holders)
 					form->priv->place_holders = g_hash_table_new_full (g_str_hash, g_str_equal,
 											   g_free, g_object_unref);
-				ph = gtk_vbox_new (FALSE, 0);
+				ph = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 				g_hash_table_insert (form->priv->place_holders, g_strdup ((gchar*) id),
 						     g_object_ref_sink ((GObject*)ph));
 				gtk_table_attach_defaults (GTK_TABLE (table), ph, 1, 2, i, i+1);
@@ -1420,7 +1422,7 @@ load_xml_layout_section (GdauiBasicForm *form, xmlNodePtr section_node)
 	xmlChar *title;
 	GtkWidget *hbox, *label, *sub, *retval;
 
-	hbox = gtk_hbox_new (FALSE, 0); /* HIG */
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0); /* HIG */
 	title = xmlGetProp (section_node, BAD_CAST "title");
 	if (title) {
 		gchar *str;
@@ -1433,7 +1435,7 @@ load_xml_layout_section (GdauiBasicForm *form, xmlNodePtr section_node)
 		gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
 
 		GtkWidget *vbox;
-		vbox = gtk_vbox_new (FALSE, 0);
+		vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 		gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 		gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 		retval = vbox;
@@ -2199,27 +2201,17 @@ gdaui_basic_form_new_in_dialog (GdaSet *data_set, GtkWindow *parent,
 		str = g_markup_printf_escaped ("<b>%s:</b>", header);
 		gtk_label_set_markup (GTK_LABEL (label), str);
 		g_free (str);
-#if GTK_CHECK_VERSION(2,18,0)
 		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
 				    label, FALSE, FALSE, SPACING);
-#else
-		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), label, FALSE, FALSE, SPACING);
-#endif
 		gtk_widget_show (label);
 	}
 
 
 	gboolean can_expand;
 	g_object_get ((GObject*) form, "can-expand-v", &can_expand, NULL);
-#if GTK_CHECK_VERSION(2,18,0)
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg)))), 4);
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))), form,
 			    can_expand, can_expand, 10);
-#else
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dlg)->vbox), 4);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), form,
-			    can_expand, can_expand, 10);
-#endif
 
 	g_signal_connect (G_OBJECT (form), "holder-changed",
 			  G_CALLBACK (form_holder_changed), dlg);
@@ -2437,7 +2429,7 @@ gdaui_basic_form_remove_from_size_group (GdauiBasicForm *form, GtkSizeGroup *siz
  * Defines the color to be used when @form displays an invalid value. Any value not
  * between 0. and 1. will result in the default hard coded values to be used (grayish).
  *
- * Since: 4.2.13
+ * Since: 5.0.3
  */
 void
 gdaui_basic_form_set_unknown_color (GdauiBasicForm *form, gdouble red, gdouble green,
